@@ -2,18 +2,21 @@ package Hades::Realm::Exporter;
 use strict;
 use warnings;
 use base qw/Hades/;
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 sub new {
 	my ( $cls, %args ) = ( shift(), scalar @_ == 1 ? %{ $_[0] } : @_ );
 	my $self      = $cls->SUPER::new(%args);
 	my %accessors = ( export => { default => {}, }, );
 	for my $accessor ( keys %accessors ) {
+		my $param
+		    = defined $args{$accessor}
+		    ? $args{$accessor}
+		    : $accessors{$accessor}->{default};
 		my $value
-		    = $self->$accessor(
-			defined $args{$accessor}
-			? $args{$accessor}
-			: $accessors{$accessor}->{default} );
+		    = $self->$accessor( $accessors{$accessor}->{builder}
+			? $accessors{$accessor}->{builder}->( $self, $param )
+			: $param );
 		unless ( !$accessors{$accessor}->{required} || defined $value ) {
 			die "$accessor accessor is required";
 		}
